@@ -19,7 +19,7 @@ class ApiCommission(BaseApi):
         # filtro de colaboradores ativos
         to_get = []
         for colsId, item in self.cols.items.items():
-            if item[self.cols.key_active] == True:
+            if item[self.cols.key_active]:
                 to_get.append(colsId)
 
         # Gerar a estrutura local com todas as comissões
@@ -35,7 +35,6 @@ class ApiCommission(BaseApi):
             length += len(self.items[key])
         return length
 
-
     def get_servs_in_cols(self, colsId):
         response = self.get(
             "/OGservsServicosComis/GservsServicosProfissionalRealiza/{}".
