@@ -6,8 +6,8 @@ from alive_progress import config_handler
 RESOLVE_ERROS = False
 NO_WARNING = False
 SKIP = False
-VERSION = "0.3.2"
+VERSION = "0.3.3"
 
 
 def config_bar():
-    config_handler.set_global(stats=False, enrich_print=False)
+    config_handler.set_global(stats=False, enrich_print=False, spinner=None)
