@@ -2,6 +2,7 @@ import random
 import re
 import string
 import unicodedata
+from datetime import datetime
 from difflib import SequenceMatcher
 import oneparams.config as config
 
@@ -88,6 +89,28 @@ def get_time(strtime: str) -> list:
         raise TypeError("Time is duplicated")
 
 
+def get_date(strdate: str) -> datetime:
+    strdate = str(strdate).strip()
+    formats = [
+        "%Y-%m-%d 00:00:00",
+        "%Y-%m-%d",
+        "%Y/%m/%d",
+        "%d/%m/%Y",
+        "%d-%m-%Y",
+    ]
+
+    date = None
+    for i in formats:
+        try:
+            date = datetime.strptime(strdate, i)
+            break
+        except ValueError:
+            continue
+    else:
+        raise ValueError("Date not found")
+    return date
+
+
 def get_num(word: str) -> str:
     """
     Retorna todos os números de uma string
@@ -161,7 +184,7 @@ def get_bool(value: any) -> bool:
     Recebe uma parâmetro (value) contendo "sim" ou "nao",
     e retorna True ou False
     """
-    if value == True or value == False:
+    if type(value) is bool:
         return value
     if value == 1:
         return True
@@ -192,3 +215,48 @@ def eprint(text: str) -> None:
 def wprint(text: str) -> None:
     if not config.NO_WARNING:
         print(text)
+
+
+def state_to_uf(state_name: str) -> str:
+    """ Retorna o UF do estado
+    """
+
+    state_name = str(state_name)
+
+    # é importante que o UF esteja em MAIUSCULO
+    # # e o estado minusculo e sem acentos
+    states = {
+        'AC': 'acre',
+        'AL': 'alagoas',
+        'AP': 'amapa',
+        'AM': 'amazonas',
+        'BA': 'bahia',
+        'CE': 'ceara',
+        'DF': 'distrito federal',
+        'ES': 'espirito santo',
+        'GO': 'goias',
+        'MA': 'maranhao',
+        'MT': 'mato grosso',
+        'MS': 'mato grosso do sul',
+        'MG': 'minas gerais',
+        'PA': 'para',
+        'PB': 'paraiba',
+        'PR': 'parana',
+        'PE': 'pernambuco',
+        'PI': 'piaui',
+        'RJ': 'rio de janeiro',
+        'RN': 'rio grande do norte',
+        'RS': 'rio grande do sul',
+        'RO': 'rondonia',
+        'RR': 'roraima',
+        'SC': 'santa catarina',
+        'SP': 'sao paulo',
+        'SE': 'sergipe',
+        'TO': 'tocantins'
+    }
+    for uf, state in states.items():
+        if (state == string_normalize(state_name) or
+                string_normalize(uf) == string_normalize(state_name)):
+            return uf
+
+    raise ValueError(f"State {state_name} not found!")
